@@ -220,27 +220,27 @@ class xtable:
                 row += ['' for i in range(wh-len(row))]
             changed = True
         if changed :
-            print("# WARNING : header and data not not well matched!", file=sys.stderr, flush=True)
+            print("# WARNING : header and data are not well matched!", file=sys.stderr, flush=True)
 
-    def json(self):
+    def json(self,force_string_typed=False):
         self.datafix()
         import json
         tbl = list()
         for r in self.__data:
             row = dict()
             for ix, val in enumerate(r):
-                row[self.__header[ix]] = val
+                row[self.__header[ix]] = (str(val) if force_string_typed else val)
             tbl.append(row)
         return json.dumps(tbl, indent=2)
 
-    def yaml(self):
+    def yaml(self,force_string_typed=False):
         self.datafix()
         import yaml
         tbl = list()
         for r in self.__data:
             row = dict()
             for ix, val in enumerate(r):
-                row[self.__header[ix]] = val
+                row[self.__header[ix]] = (str(val) if force_string_typed else val)
             tbl.append(row)
         return yaml.safe_dump(tbl, default_flow_style=False)
 
@@ -382,13 +382,13 @@ class xtable:
             return (is_a_tty or iscygwin) and (m or supported_platform)
 
         colored = False
-        if supports_color() or os.environ.get(
-                "force_ansicolor", "").lower() in ["true", "yes", "y", "1"]:
+        if supports_color() :
             colored = True
         if self.__force_colored :
             colored = self.__force_colored
-        if os.environ.get("force_ansicolor",
-                          "").lower() in ["false", "no", "n", "0"]:
+        if os.environ.get("force_ansicolor", "").lower() in ["true", "yes", "y", "1"]:
+            colored = True
+        elif os.environ.get("force_ansicolor", "").lower() in ["false", "no", "n", "0"]:
             colored = False
 
         if self.__superwrap:
@@ -637,6 +637,13 @@ def xtable_main():
         default=False,
         help="indicate there's no header",
     )
+    parser.add_argument(
+        "--force_string_typed",
+        dest="forcestring",
+        action="store_true",
+        default=False,
+        help="force string type when dumping JSON/YAML to skip data type limit",
+    )
     parser.add_argument(
         "--tree",
         dest="tree",
@@ -684,9 +691,9 @@ def xtable_main():
             print(t.pivot())
         else:
             if args.format == "json":
-                print(t.json(), end="")
+                print(t.json(force_string_typed=args.forcestring), end="")
             elif args.format == "yaml":
-                print(t.yaml(), end="")
+                print(t.yaml(force_string_typed=args.forcestring), end="")
             elif args.format == "csv":
                 print(t.csv(), end="")
             elif args.format == "html":
